@@ -56,8 +56,9 @@ class RedisClientTaskCourier(FullQueueNameMixin, BaseClientTaskCourier):
 
     def get_task_result(
             self, queue_name, task_id, delete_data=True):
-        """Returns task retuls, if it exists.
-        Otherwise, raises exceptions.TaskResultDoesNotExist
+        """Returns task retult, if it exists.
+        Otherwise, raises exceptions.TaskResultDoesNotExist. If an error occurs
+        during the execution of the task raises exceptions.PerformTaskError.
         Client side method.
 
         - queue_name - queue name, used in the add_task_to_queue method.
@@ -72,13 +73,17 @@ class RedisClientTaskCourier(FullQueueNameMixin, BaseClientTaskCourier):
             raw_data = self.redis_connection.get(name=name)
         if raw_data is None:
             raise exceptions.TaskResultDoesNotExist
-        return pickle.loads(raw_data)
+        result = pickle.loads(raw_data)
+        if isinstance(result, exceptions.PerformTaskError):
+            raise result
+        return result
 
     def wait_for_task_result(
             self, queue_name, task_id, delete_data=True, timeout=None):
-        """Waits for the task result to appear, and then returns it.
-        Blocking method. Checks every self.refresh_timeout seconds for
-        a result availability. Raises TimeoutError in case of timeout.
+        """Waits for the task result to appear, and then returns it. Blocking
+        method. Checks every self.refresh_timeout seconds for a result.
+        Raises TimeoutError in case of timeout. If an error occurs during the
+        execution of the task raises exceptions.PerformTaskError.
         Client side method.
 
         - queue_name - queue name, used in the add_task_to_queue method.
@@ -119,6 +124,14 @@ class RedisClientTaskCourier(FullQueueNameMixin, BaseClientTaskCourier):
             task)
         return task_id
 
+    def check_for_done(self, queue_name, task_id):
+        """Checks if the task has completed.
+        Returns True - if task is done (successful or unsuccessful),
+        or False if there is no task result yet."""
+
+        name = self._get_full_queue_name(queue_name, "results:") + str(task_id)
+        return self.redis_connection.exists(name)
+
 
 class RedisWorkerTaskCourier(FullQueueNameMixin, BaseWorkerTaskCourier):
     """
@@ -189,7 +202,7 @@ class RedisWorkerTaskCourier(FullQueueNameMixin, BaseWorkerTaskCourier):
         task_id, task_data = pickle.loads(task[-1])
         return task_id, task_data
 
-    def return_task_result(self, queue_name, task_id, task_data):
+    def return_task_result(self, queue_name, task_id, task_result):
         """Return the result of processing the task to the client via redis.
         Worker side method.
 
@@ -199,7 +212,7 @@ class RedisWorkerTaskCourier(FullQueueNameMixin, BaseWorkerTaskCourier):
 
         name = self._get_full_queue_name(
             queue_name=queue_name, sufix="results:") + str(task_id)
-        value = pickle.dumps(task_data)
+        value = pickle.dumps(task_result)
         self.redis_connection.set(name=name, value=value,
                                   ex=self.result_timeout)
 
