@@ -90,6 +90,10 @@ class RedisClientTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
     class TimeoutTestException(TimeoutError):
         pass
 
+    def test__generate_task_id(self):
+        task_id = self.task_courier._generate_task_id()
+        self.assertEqual(type(task_id), uuid.UUID)
+
     def test_add_task_to_queue_as_dict(self):
         start_task_data = {
             "test_key": "test_value",
@@ -171,6 +175,23 @@ class RedisClientTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
                 queue_name="test_queue_name",
                 task_id=task_id)
 
+    def test_get_task_result_if_result_is_PerformTaskError(self):
+        before_task_result = exceptions.PerformTaskError(
+            exception=Exception(), error_data="ERROR TEXT")
+        before_task_id = uuid.uuid1()
+        key_name = self.task_courier._get_full_queue_name(
+            queue_name="test_queue_name",
+            sufix="results:") + str(before_task_id)
+        value = pickle.dumps(before_task_result)
+        self.redis_connection.set(name=key_name, value=value)
+
+        with self.assertRaises(exceptions.PerformTaskError) as context:
+            self.task_courier.get_task_result(
+                queue_name="test_queue_name",
+                task_id=before_task_id)
+        self.assertEqual(type(context.exception.exception), Exception)
+        self.assertEqual(context.exception.error_data, "ERROR TEXT")
+
     def test_wait_for_task_result_if_delete_data_True(self):
         before_task_result = "test_result_123"
         before_task_id = uuid.uuid1()
@@ -255,6 +276,49 @@ class RedisClientTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
 
         self.assertEqual(before_task_result, after_task_result)
 
+    def test_check_for_done_if_not_done(self):
+        before_task_id = uuid.uuid1()
+        done_status = self.task_courier.check_for_done(
+            queue_name="test_queue_name",
+            task_id=before_task_id)
+        self.assertEqual(done_status, False)
+
+    def test_check_for_done_if_done_successfully(self):
+        before_task_result = "test_result_123"
+        before_task_id = uuid.uuid1()
+        key_name = self.task_courier._get_full_queue_name(
+            queue_name="test_queue_name",
+            sufix="results:") + str(before_task_id)
+        value = pickle.dumps(before_task_result)
+        self.redis_connection.set(name=key_name, value=value)
+        done_status = self.task_courier.check_for_done(
+            queue_name="test_queue_name",
+            task_id=before_task_id)
+        after_task_result = self.task_courier.get_task_result(
+            queue_name="test_queue_name",
+            task_id=before_task_id)
+
+        self.assertEqual(done_status, True)
+        self.assertEqual(after_task_result, before_task_result)
+
+    def test_check_for_done_if_done_with_error(self):
+        before_task_result = exceptions.PerformTaskError(
+            exception=Exception())
+        before_task_id = uuid.uuid1()
+        key_name = self.task_courier._get_full_queue_name(
+            queue_name="test_queue_name",
+            sufix="results:") + str(before_task_id)
+        value = pickle.dumps(before_task_result)
+        self.redis_connection.set(name=key_name, value=value)
+        done_status = self.task_courier.check_for_done(
+            queue_name="test_queue_name",
+            task_id=before_task_id)
+        with self.assertRaises(exceptions.PerformTaskError):
+            self.task_courier.get_task_result(
+                queue_name="test_queue_name",
+                task_id=before_task_id)
+        self.assertEqual(done_status, True)
+
 
 class RedisWorkerTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
     """
@@ -272,18 +336,18 @@ class RedisWorkerTaskCourierTestCase(RedisSetupMixin, unittest.TestCase):
     def test_return_task_result(self):
         queue_name = "test_queue"
         task_id = uuid.uuid1()
-        task_data = "test_data_test_return_task_result"
+        task_result = "test_data_test_return_task_result"
         self.task_courier.result_timeout = 1
 
         self.task_courier.return_task_result(
             queue_name=queue_name,
             task_id=task_id,
-            task_data=task_data)
+            task_result=task_result)
 
         name = self.task_courier._get_full_queue_name(
             queue_name=queue_name, sufix="results:") + str(task_id)
         value = pickle.loads(self.redis_connection.get(name))
-        self.assertEqual(value, task_data)
+        self.assertEqual(value, task_result)
         time.sleep(2)
         value = self.redis_connection.get(name)
         self.assertIsNone(value)
